@@ -123,7 +123,11 @@ class model:
                 self.input_count = int(input("Number of input neurons: "))
                 self.hidden_count = int(input("Number of hidden neurons: "))
                 self.output_count = int(input("Number of output neurons: "))
-                self.activation_values = [4 for i in range(2)]+[6]
+                
+                self.activation_values = activation_values
+                
+                if len(self.activation_values) == 0:
+                    self.activation_values = [4 for i in range(4)]
 
                 if softmax:
                     self.activation_values += [100]
